# Aerospike Telemetry Agent Documentation

The Aerospike Telemetry Agent collects anonymized usage statistics from an Aerospike server running on the same machine and forwards the data so obtained to Aerospike.

## Theory of Operation

The usage statistics are obtained via sending various Info. commands to the Aerospike server on its service port. The Aerospike server's service port is determined by parsing the Aerospike server configuration file, which must be provided as the value of the `config-file` property in the `[asd]` section of the Telemetry Agent configuration file. Some basic system-level statistics are also obtained from the host machine.

## Running the Telemetry Agent

1). Use Git to clone the `aerospike-telemetry-agent` repository.

2). `cd aerospike-telemetry-agent`

3). You may run `./telemetry.py --help` for usage:

```
$ ./telemetry.py --help
Usage: ./telemetry.py [options] <ConfigFile> [<Service Action for Daemon Mode: (start|stop|status|restart|try-restart)>]

Options:
  -h, --help            show this help message and exit
  --disable             Disable Telemetry Agent. (Requires agent restart to
                        take effect.)
  --enable              Enable Telemetry Agent. (Requires agent restart to
                        take effect.)
  --fgdaemon            Enable foreground daemon mode.
  --set-cafile=<CAFILE>
                        Set certificate authority file.
  --set-email=<EMAIL>   Set email address.
  --set-group=<GROUP>   Set daemon group.
  --set-interval=<INTERVAL>
                        Set data collection and reporting interval.
  --set-logfile=<LOGFILE>
                        Set log file.
  --set-loglevel=<LOGLEVEL>
                        Set log level.
  --set-proxy=<PROXY>   Set HTTPS proxy.
  --set-user=<USER>     Set daemon user.
  --sample              Sample data once and print the result.
```

4). The single required argument is the Telemetry Agent configuration file.

For reference purposes, a example configuration file is provided as `telemetry_sample.conf`. (The 'real' generally comes from the Aerospike server source code tree.)

5). You may supply a command-line option to edit the configuration file.

Example usage:

```
$ ./telemetry.py telemetry.conf --set-logfile=out
```

6). Otherwise, you must supply a service action (`start`, `stop`, `status`, `restart`, or `try-restart`) for running the Telemetry Agent as a daemon.

Example usage:

```
$ ./telemetry.py telemetry.conf start
```

**Note**:  The `--fgdaemon` option is used with the `start` command under `systemd` to run the Telemetry Agent as a "new style" (foreground) daemon.

## Configuration

The Telemetry Agent uses the parameters present in the configuration file. These parameters can be changed by directly editing the configuration file or by using the command line tool as detailed in the usage output above.

A sample development configuration file might look like:

```
[asd]
config-file = /etc/aerospike/aerospike.conf

[logging]
logfile = out
loglevel = debug

[main]
disable = false
interval = 600
home-url = https://telemetry.aerospike.com
email =
user = aerospike
group = aerospike
```

## Disabling/Enabling the Telemetry Agent

There are two ways to disable/enable the Telemetry Agent:

1). Directly edit the configuration file.

 When ASD is installed via a DEB or RPM package, the configuration file is stored as: `/etc/aerospike/telemetry.conf`.

To disable (or enable) the agent, set the `disable` value in the file to `true` (or `false`.)

2). Use the Telemetry Agent command line interface.

When ASD is installed via a DEB or RPM package, the main Telemetry Agent script is stored as: `/opt/aerospike/telemetry/telemetry.py`.

To disable (or enable) the Telemetry Agent, run:

	$ /opt/aerospike/telemetry/telemetry.py /etc/aerospike/telemetry.conf --disable

or

	$ /opt/aerospike/telemetry/telemetry.py /etc/aerospike/telemetry.conf --enable

If you're running from within the repository, run:

	$ <repo path>/modules/telemetry/telemetry.py <repo path>/as/etc/telemetry_dev.conf --disable

or

	$ <repo path>/modules/telemetry/telemetry.py <repo path>/as/etc/telemetry_dev.conf --enable

If Aerospike is already running when using either of the above methods, you must restart Aerospike (or just the Telemetry Agent) for the change to take effect:

On most distros (based on SysV Init.), use:

	$ service aerospike restart

or

	$ service aerospike_telemetry restart

Under `systemd`-based distros (RedHat EL7+-based distros (e.g., RHEL 7+, CentOS 7+, Fedora 15+), Debian 8+, and Ubuntu 16+), use:

	$ systemctl restart aerospike

or

	$ systemctl restart aerospike_telemetry

or, when ASD is run from within the open source tree (i.e., GitHub repo.):

	$ make stop start

## Data Format

The following is an example of the format of the data sent from the Telemetry Agent to Aerospike:
[*Note:*  Not all fields are sent at all times.  Infrequently-changing or
potentially-verbose fields (specifically, `config`, `sets`, `sindex-metadata`,
`sindexes`, and `system`) are generally sent only once per day.]

	{ 'bins': { '098f6bcd4621d373cade4e832627b4f6': { 'bin_names': '15',
	                                                  'bin_names_quota': '32768'},
	            '37b51d194a7513e45b56f6524f2d51f2': { 'bin_names': '0',
	                                                  'bin_names_quota': '32768'}},
	  'build': '4.7.0.5',
	  'build_os': 'el6',
	  'build_time': 'Wed Nov 13 00:18:09 UTC 2019'
	  'cluster-name': 'd41d8cd98f00b204e9800998ecf8427e',
	  'config': { 'advertise-ipv6': 'false',
	              'auto-pin': 'none',
	              'batch-index-threads': '4',
	              'batch-max-buffers-per-queue': '255',
	              'batch-max-requests': '5000',
	              'batch-max-unused-buffers': '256',
	              'cluster-name': 'null',
	              'debug-allocations': 'none',
	              'enable-benchmarks-fabric': 'false',
	              'enable-health-check': 'false',
	              'enable-hist-info': 'false',
	              'enable-ldap': 'false',
	              'enable-security': 'false',
	              'fabric-dump-msgs': 'false',
	              'fabric.channel-bulk-fds': '2',
	              'fabric.channel-bulk-recv-threads': '4',
	              'fabric.channel-ctrl-fds': '1',
	              'fabric.channel-ctrl-recv-threads': '4',
	              'fabric.channel-meta-fds': '1',
	              'fabric.channel-meta-recv-threads': '4',
	              'fabric.channel-rw-fds': '8',
	              'fabric.channel-rw-recv-threads': '16',
	              'fabric.keepalive-enabled': 'true',
	              'fabric.keepalive-intvl': '1',
	              'fabric.keepalive-probes': '10',
	              'fabric.keepalive-time': '1',
	              'fabric.latency-max-ms': '5',
	              'fabric.port': '3001',
	              'fabric.recv-rearm-threshold': '1024',
	              'fabric.send-threads': '8',
	              'fabric.tls-name': 'null',
	              'fabric.tls-port': '0',
	              'feature-key-file': '/etc/aerospike/features.conf',
	              'heartbeat.interval': '150',
	              'heartbeat.mesh-seed-address-port': '98315ce693114ad9d0229d5d1f59303a:3002;372a4587ae1088b86c9f4f3fb77b28fe:3002',
	              'heartbeat.mode': 'mesh',
	              'heartbeat.mtu': '1500',
	              'heartbeat.port': '3002',
	              'heartbeat.protocol': 'v3',
	              'heartbeat.timeout': '10',
	              'heartbeat.tls-name': 'null',
	              'heartbeat.tls-port': '0',
	              'hist-track-back': '300',
	              'hist-track-slice': '10',
	              'hist-track-thresholds': 'null',
	              'indent-allocations': 'false',
	              'info-threads': '16',
	              'info.port': '3003',
	              'keep-caps-ssd-health': 'false',
	              'ldap-login-threads': '8',
	              'ldap.disable-tls': 'false',
	              'ldap.polling-period': '300',
	              'ldap.query-base-dn': 'null',
	              'ldap.query-user-dn': 'null',
	              'ldap.query-user-password-file': 'null',
	              'ldap.role-query-base-dn': 'null',
	              'ldap.role-query-search-ou': 'false',
	              'ldap.server': 'null',
	              'ldap.session-ttl': '86400',
	              'ldap.tls-ca-file': 'null',
	              'ldap.token-hash-method': 'sha-256',
	              'ldap.user-dn-pattern': 'null',
	              'ldap.user-query-pattern': 'null',
	              'log-local-time': 'false',
	              'log-millis': 'false',
	              'migrate-fill-delay': '0',
	              'migrate-max-num-incoming': '4',
	              'migrate-threads': '1',
	              'min-cluster-size': '1',
	              'node-id': 'a2f9f2f6fc2d1a6866870a99cbec6151',
	              'node-id-interface': 'null',
	              'paxos-single-replica-limit': '1',
	              'pidfile': '/var/run/aerospike/asd.pid',
	              'privilege-refresh-period': '300',
	              'proto-fd-idle-ms': '60000',
	              'proto-fd-max': '15000',
	              'proto-slow-netio-sleep-ms': '1',
	              'query-batch-size': '100',
	              'query-buf-size': '2097152',
	              'query-bufpool-size': '256',
	              'query-in-transaction-thread': 'false',
	              'query-long-q-max-size': '500',
	              'query-microbenchmark': 'false',
	              'query-pre-reserve-partitions': 'false',
	              'query-priority': '10',
	              'query-priority-sleep-us': '1',
	              'query-rec-count-bound': '18446744073709551615',
	              'query-req-in-query-thread': 'false',
	              'query-req-max-inflight': '100',
	              'query-short-q-max-size': '500',
	              'query-threads': '6',
	              'query-threshold': '10',
	              'query-untracked-time-ms': '1000',
	              'query-worker-threads': '15',
	              'report-authentication-sinks': '0',
	              'report-data-op-sinks': '0',
	              'report-sys-admin-sinks': '0',
	              'report-user-admin-sinks': '0',
	              'report-violation-sinks': '0',
	              'run-as-daemon': 'true',
	              'scan-max-done': '100',
	              'scan-threads-limit': '128',
	              'service-threads': '4',
	              'service.access-port': '0',
	              'service.address': '100b8cad7cf2a56f6df78f171f97a1ec',
	              'service.alternate-access-port': '0',
	              'service.port': '3000',
	              'service.tls-access-port': '0',
	              'service.tls-alternate-access-port': '0',
	              'service.tls-name': 'null',
	              'service.tls-port': '0',
	              'sindex-builder-threads': '4',
	              'sindex-gc-max-rate': '50000',
	              'sindex-gc-period': '10',
	              'syslog-local': '-1',
	              'ticker-interval': '10',
	              'transaction-max-ms': '1000',
	              'transaction-retry-ms': '1002',
	              'work-directory': '/opt/aerospike'},
	  'dmi': { 'bios_date': '02/16/2012',
	           'bios_vendor': 'American Megatrends Inc.',
	           'bios_version': '0801',
	           'board_asset_tag': 'To be filled by O.E.M.',
	           'board_name': 'P8Z77-M PRO',
	           'board_vendor': 'ASUSTeK COMPUTER INC.',
	           'board_version': 'Rev 1.xx',
	           'chassis_asset_tag': 'Asset-1234567890',
	           'chassis_type': '3',
	           'chassis_vendor': 'Chassis Manufacture',
	           'chassis_version': 'Chassis Version',
	           'modalias': 'dmi:bvnAmericanMegatrendsInc.:bvr0801:bd02/16/2012:svnSystemmanufacturer:pnSystemProductName:pvrSystemVersion:rvnASUSTeKCOMPUTERINC.:rnP8Z77-MPRO:rvrRev1.xx:cvnChassisManufacture:ct3:cvrChassisVersion:',
	           'product_name': 'System Product Name',
	           'product_version': 'System Version',
	           'smbios_version': '2.7',
	           'sys_vendor': 'System manufacturer',
	           'uevent': 'MODALIAS=dmi:bvnAmericanMegatrendsInc.:bvr0801:bd02/16/2012:svnSystemmanufacturer:pnSystemProductName:pvrSystemVersion:rvnASUSTeKCOMPUTERINC.:rnP8Z77-MPRO:rvrRev1.xx:cvnChassisManufacture:ct3:cvrChassisVersion:'},
	  'edition': 'Aerospike Community Edition',
	  'features': 'batch-index;blob-bits;cdt-list;cdt-map;cluster-stable;float;geo;sindex-exists;peers;pipelining;relaxed-sc;replicas;replicas-all;replicas-master;truncate-namespace;udf',
	  'histograms': { '098f6bcd4621d373cade4e832627b4f6': { 'latency': { 'query': 'error-no-data-yet-or-back-too-small',
	                                                                     'read': 'error-no-data-yet-or-back-too-small',
	                                                                     'udf': 'error-no-data-yet-or-back-too-small',
	                                                                     'write': 'error-no-data-yet-or-back-too-small'},
	                                                        'throughput': { 'query': 'error-no-data-yet-or-back-too-small',
	                                                                        'read': 'error-no-data-yet-or-back-too-small',
	                                                                        'udf': 'error-no-data-yet-or-back-too-small',
	                                                                        'write': 'error-no-data-yet-or-back-too-small'}},
	                  '37b51d194a7513e45b56f6524f2d51f2': { 'latency': { 'query': 'error-no-data-yet-or-back-too-small',
	                                                                     'read': 'error-no-data-yet-or-back-too-small',
	                                                                     'udf': 'error-no-data-yet-or-back-too-small',
	                                                                     'write': 'error-no-data-yet-or-back-too-small'},
	                                                        'throughput': { 'query': 'error-no-data-yet-or-back-too-small',
	                                                                        'read': 'error-no-data-yet-or-back-too-small',
	                                                                        'udf': 'error-no-data-yet-or-back-too-small',
	                                                                        'write': 'error-no-data-yet-or-back-too-small'}}},
	  'interval': '600',
	  'meminfo': { 'Active': '898416 kB',
	               'Active(anon)': '109628 kB',
	               'Active(file)': '788788 kB',
	               'AnonHugePages': '10240 kB',
	               'AnonPages': '61724 kB',
	               'Bounce': '0 kB',
	               'Buffers': '233088 kB',
	               'Cached': '2438052 kB',
	               'CommitLimit': '81986524 kB',
	               'Committed_AS': '1486004 kB',
	               'DirectMap2M': '33445888 kB',
	               'DirectMap4k': '8192 kB',
	               'Dirty': '24 kB',
	               'HardwareCorrupted': '0 kB',
	               'HugePages_Free': '0',
	               'HugePages_Rsvd': '0',
	               'HugePages_Surp': '0',
	               'HugePages_Total': '0',
	               'Hugepagesize': '2048 kB',
	               'Inactive': '1882056 kB',
	               'Inactive(anon)': '3480 kB',
	               'Inactive(file)': '1878576 kB',
	               'KernelStack': '2096 kB',
	               'Mapped': '19752 kB',
	               'MemFree': '29503492 kB',
	               'MemTotal': '32898740 kB',
	               'Mlocked': '0 kB',
	               'NFS_Unstable': '0 kB',
	               'PageTables': '5240 kB',
	               'SReclaimable': '182964 kB',
	               'SUnreclaim': '28968 kB',
	               'Shmem': '3776 kB',
	               'Slab': '211932 kB',
	               'SwapCached': '0 kB',
	               'SwapFree': '65537156 kB',
	               'SwapTotal': '65537156 kB',
	               'Unevictable': '0 kB',
	               'VmallocChunk': '34359310228 kB',
	               'VmallocTotal': '34359738367 kB',
	               'VmallocUsed': '422616 kB',
	               'Writeback': '0 kB',
	               'WritebackTmp': '0 kB'},
	  'namespaces': { '098f6bcd4621d373cade4e832627b4f6': { 'allow-nonxdr-writes': 'true',
	                                                        'allow-xdr-writes': 'true',
	                                                        'appeals_records_exonerated': '0',
	                                                        'appeals_rx_active': '0',
	                                                        'appeals_tx_active': '0',
	                                                        'appeals_tx_remaining': '0',
	                                                        'available_bin_names': '32753',
	                                                        'background-scan-max-rps': '10000',
	                                                        'batch_sub_proxy_complete': '0',
	                                                        'batch_sub_proxy_error': '0',
	                                                        'batch_sub_proxy_timeout': '0',
	                                                        'batch_sub_read_error': '0',
	                                                        'batch_sub_read_filtered_out': '0',
	                                                        'batch_sub_read_not_found': '0',
	                                                        'batch_sub_read_success': '0',
	                                                        'batch_sub_read_timeout': '0',
	                                                        'batch_sub_tsvc_error': '0',
	                                                        'batch_sub_tsvc_timeout': '0',
	                                                        'client_delete_error': '0',
	                                                        'client_delete_filtered_out': '0',
	                                                        'client_delete_not_found': '0',
	                                                        'client_delete_success': '0',
	                                                        'client_delete_timeout': '0',
	                                                        'client_lang_delete_success': '0',
	                                                        'client_lang_error': '0',
	                                                        'client_lang_read_success': '0',
	                                                        'client_lang_write_success': '0',
	                                                        'client_proxy_complete': '0',
	                                                        'client_proxy_error': '0',
	                                                        'client_proxy_timeout': '0',
	                                                        'client_read_error': '0',
	                                                        'client_read_filtered_out': '0',
	                                                        'client_read_not_found': '0',
	                                                        'client_read_success': '0',
	                                                        'client_read_timeout': '0',
	                                                        'client_tsvc_error': '0',
	                                                        'client_tsvc_timeout': '0',
	                                                        'client_udf_complete': '0',
	                                                        'client_udf_error': '0',
	                                                        'client_udf_filtered_out': '0',
	                                                        'client_udf_timeout': '0',
	                                                        'client_write_error': '0',
	                                                        'client_write_filtered_out': '0',
	                                                        'client_write_success': '0',
	                                                        'client_write_timeout': '0',
	                                                        'clock_skew_stop_writes': 'false',
	                                                        'conflict-resolution-policy': 'generation',
	                                                        'current_time': '313299633',
	                                                        'data-in-index': 'false',
	                                                        'dead_partitions': '0',
	                                                        'default-ttl': '2592000',
	                                                        'deleted_last_bin': '0',
	                                                        'disable-cold-start-eviction': 'false',
	                                                        'disable-write-dup-res': 'false',
	                                                        'disallow-null-setname': 'false',
	                                                        'effective_is_quiesced': 'false',
	                                                        'effective_prefer_uniform_balance': 'false',
	                                                        'effective_replication_factor': '0',
	                                                        'enable-benchmarks-batch-sub': 'false',
	                                                        'enable-benchmarks-read': 'false',
	                                                        'enable-benchmarks-udf': 'false',
	                                                        'enable-benchmarks-udf-sub': 'false',
	                                                        'enable-benchmarks-write': 'false',
	                                                        'enable-hist-proxy': 'false',
	                                                        'enable-xdr': 'false',
	                                                        'evict-hist-buckets': '10000',
	                                                        'evict-tenths-pct': '5',
	                                                        'evict_ttl': '0',
	                                                        'evict_void_time': '0',
	                                                        'evicted_objects': '0',
	                                                        'expired_objects': '0',
	                                                        'fail_generation': '0',
	                                                        'fail_key_busy': '0',
	                                                        'fail_record_too_big': '0',
	                                                        'fail_xdr_forbidden': '0',
	                                                        'from_proxy_batch_sub_read_error': '0',
	                                                        'from_proxy_batch_sub_read_filtered_out': '0',
	                                                        'from_proxy_batch_sub_read_not_found': '0',
	                                                        'from_proxy_batch_sub_read_success': '0',
	                                                        'from_proxy_batch_sub_read_timeout': '0',
	                                                        'from_proxy_batch_sub_tsvc_error': '0',
	                                                        'from_proxy_batch_sub_tsvc_timeout': '0',
	                                                        'from_proxy_delete_error': '0',
	                                                        'from_proxy_delete_filtered_out': '0',
	                                                        'from_proxy_delete_not_found': '0',
	                                                        'from_proxy_delete_success': '0',
	                                                        'from_proxy_delete_timeout': '0',
	                                                        'from_proxy_lang_delete_success': '0',
	                                                        'from_proxy_lang_error': '0',
	                                                        'from_proxy_lang_read_success': '0',
	                                                        'from_proxy_lang_write_success': '0',
	                                                        'from_proxy_read_error': '0',
	                                                        'from_proxy_read_filtered_out': '0',
	                                                        'from_proxy_read_not_found': '0',
	                                                        'from_proxy_read_success': '0',
	                                                        'from_proxy_read_timeout': '0',
	                                                        'from_proxy_tsvc_error': '0',
	                                                        'from_proxy_tsvc_timeout': '0',
	                                                        'from_proxy_udf_complete': '0',
	                                                        'from_proxy_udf_error': '0',
	                                                        'from_proxy_udf_filtered_out': '0',
	                                                        'from_proxy_udf_timeout': '0',
	                                                        'from_proxy_write_error': '0',
	                                                        'from_proxy_write_filtered_out': '0',
	                                                        'from_proxy_write_success': '0',
	                                                        'from_proxy_write_timeout': '0',
	                                                        'geo2dsphere-within.earth-radius-meters': '6371000',
	                                                        'geo2dsphere-within.level-mod': '1',
	                                                        'geo2dsphere-within.max-cells': '12',
	                                                        'geo2dsphere-within.max-level': '30',
	                                                        'geo2dsphere-within.min-level': '1',
	                                                        'geo2dsphere-within.strict': 'true',
	                                                        'geo_region_query_cells': '0',
	                                                        'geo_region_query_falsepos': '0',
	                                                        'geo_region_query_points': '0',
	                                                        'geo_region_query_reqs': '0',
	                                                        'high-water-disk-pct': '50',
	                                                        'high-water-memory-pct': '60',
	                                                        'hwm_breached': 'false',
	                                                        'index-stage-size': '1073741824',
	                                                        'index-type': 'undefined',
	                                                        'master_objects': '0',
	                                                        'master_tombstones': '0',
	                                                        'memory-size': '4294967296',
	                                                        'memory_free_pct': '99',
	                                                        'memory_used_bytes': '278528',
	                                                        'memory_used_data_bytes': '0',
	                                                        'memory_used_index_bytes': '0',
	                                                        'memory_used_sindex_bytes': '278528',
	                                                        'migrate-order': '5',
	                                                        'migrate-retransmit-ms': '5000',
	                                                        'migrate-sleep': '1',
	                                                        'migrate_record_receives': '0',
	                                                        'migrate_record_retransmits': '0',
	                                                        'migrate_records_skipped': '0',
	                                                        'migrate_records_transmitted': '0',
	                                                        'migrate_rx_instances': '0',
	                                                        'migrate_rx_partitions_active': '0',
	                                                        'migrate_rx_partitions_initial': '0',
	                                                        'migrate_rx_partitions_remaining': '0',
	                                                        'migrate_signals_active': '0',
	                                                        'migrate_signals_remaining': '0',
	                                                        'migrate_tx_instances': '0',
	                                                        'migrate_tx_partitions_active': '0',
	                                                        'migrate_tx_partitions_imbalance': '0',
	                                                        'migrate_tx_partitions_initial': '0',
	                                                        'migrate_tx_partitions_lead_remaining': '0',
	                                                        'migrate_tx_partitions_remaining': '0',
	                                                        'nodes_quiesced': '0',
	                                                        'non_expirable_objects': '0',
	                                                        'non_replica_objects': '0',
	                                                        'non_replica_tombstones': '0',
	                                                        'ns-forward-xdr-writes': 'false',
	                                                        'ns_cluster_size': '0',
	                                                        'nsup-hist-period': '3600',
	                                                        'nsup-period': '120',
	                                                        'nsup-threads': '1',
	                                                        'nsup_cycle_duration': '0',
	                                                        'objects': '0',
	                                                        'ops_sub_tsvc_error': '0',
	                                                        'ops_sub_tsvc_timeout': '0',
	                                                        'ops_sub_write_error': '0',
	                                                        'ops_sub_write_filtered_out': '0',
	                                                        'ops_sub_write_success': '0',
	                                                        'ops_sub_write_timeout': '0',
	                                                        'partition-tree-sprigs': '256',
	                                                        'pending_quiesce': 'false',
	                                                        'prefer-uniform-balance': 'false',
	                                                        'prole_objects': '0',
	                                                        'prole_tombstones': '0',
	                                                        'query_agg': '0',
	                                                        'query_agg_abort': '0',
	                                                        'query_agg_avg_rec_count': '0',
	                                                        'query_agg_error': '0',
	                                                        'query_agg_success': '0',
	                                                        'query_fail': '0',
	                                                        'query_long_queue_full': '0',
	                                                        'query_long_reqs': '0',
	                                                        'query_lookup_abort': '0',
	                                                        'query_lookup_avg_rec_count': '0',
	                                                        'query_lookup_error': '0',
	                                                        'query_lookup_success': '0',
	                                                        'query_lookups': '0',
	                                                        'query_ops_bg_failure': '0',
	                                                        'query_ops_bg_success': '0',
	                                                        'query_proto_compression_ratio': '1.000',
	                                                        'query_proto_uncompressed_pct': '0.000',
	                                                        'query_reqs': '0',
	                                                        'query_short_queue_full': '0',
	                                                        'query_short_reqs': '0',
	                                                        'query_udf_bg_failure': '0',
	                                                        'query_udf_bg_success': '0',
	                                                        'rack-id': '0',
	                                                        're_repl_error': '0',
	                                                        're_repl_success': '0',
	                                                        're_repl_timeout': '0',
	                                                        'read-consistency-level-override': 'off',
	                                                        'record_proto_compression_ratio': '1.000',
	                                                        'record_proto_uncompressed_pct': '0.000',
	                                                        'replication-factor': '2',
	                                                        'retransmit_all_batch_sub_dup_res': '0',
	                                                        'retransmit_all_delete_dup_res': '0',
	                                                        'retransmit_all_delete_repl_write': '0',
	                                                        'retransmit_all_read_dup_res': '0',
	                                                        'retransmit_all_udf_dup_res': '0',
	                                                        'retransmit_all_udf_repl_write': '0',
	                                                        'retransmit_all_write_dup_res': '0',
	                                                        'retransmit_all_write_repl_write': '0',
	                                                        'retransmit_ops_sub_dup_res': '0',
	                                                        'retransmit_ops_sub_repl_write': '0',
	                                                        'retransmit_udf_sub_dup_res': '0',
	                                                        'retransmit_udf_sub_repl_write': '0',
	                                                        'scan_aggr_abort': '0',
	                                                        'scan_aggr_complete': '0',
	                                                        'scan_aggr_error': '0',
	                                                        'scan_basic_abort': '0',
	                                                        'scan_basic_complete': '0',
	                                                        'scan_basic_error': '0',
	                                                        'scan_ops_bg_abort': '0',
	                                                        'scan_ops_bg_complete': '0',
	                                                        'scan_ops_bg_error': '0',
	                                                        'scan_proto_compression_ratio': '1.000',
	                                                        'scan_proto_uncompressed_pct': '0.000',
	                                                        'scan_udf_bg_abort': '0',
	                                                        'scan_udf_bg_complete': '0',
	                                                        'scan_udf_bg_error': '0',
	                                                        'sets-enable-xdr': 'true',
	                                                        'sindex.num-partitions': '32',
	                                                        'single-bin': 'false',
	                                                        'single-scan-threads': '4',
	                                                        'smd_evict_void_time': '0',
	                                                        'stop-writes-pct': '90',
	                                                        'stop_writes': 'false',
	                                                        'storage-engine': 'memory',
	                                                        'strong-consistency': 'false',
	                                                        'strong-consistency-allow-expunge': 'false',
	                                                        'tomb-raider-eligible-age': '86400',
	                                                        'tomb-raider-period': '86400',
	                                                        'tombstones': '0',
	                                                        'transaction-pending-limit': '20',
	                                                        'truncate-threads': '4',
	                                                        'truncate_lut': '0',
	                                                        'truncated_records': '0',
	                                                        'udf_sub_lang_delete_success': '0',
	                                                        'udf_sub_lang_error': '0',
	                                                        'udf_sub_lang_read_success': '0',
	                                                        'udf_sub_lang_write_success': '0',
	                                                        'udf_sub_tsvc_error': '0',
	                                                        'udf_sub_tsvc_timeout': '0',
	                                                        'udf_sub_udf_complete': '0',
	                                                        'udf_sub_udf_error': '0',
	                                                        'udf_sub_udf_filtered_out': '0',
	                                                        'udf_sub_udf_timeout': '0',
	                                                        'unavailable_partitions': '0',
	                                                        'write-commit-level-override': 'off',
	                                                        'xdr_client_delete_error': '0',
	                                                        'xdr_client_delete_not_found': '0',
	                                                        'xdr_client_delete_success': '0',
	                                                        'xdr_client_delete_timeout': '0',
	                                                        'xdr_client_write_error': '0',
	                                                        'xdr_client_write_success': '0',
	                                                        'xdr_client_write_timeout': '0',
	                                                        'xdr_from_proxy_delete_error': '0',
	                                                        'xdr_from_proxy_delete_not_found': '0',
	                                                        'xdr_from_proxy_delete_success': '0',
	                                                        'xdr_from_proxy_delete_timeout': '0',
	                                                        'xdr_from_proxy_write_error': '0',
	                                                        'xdr_from_proxy_write_success': '0',
	                                                        'xdr_from_proxy_write_timeout': '0',
	                                                        'xmem_id': '0',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-query-hist-track-back': '300',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-query-hist-track-slice': '10',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-query-hist-track-thresholds': '1,8,64',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-read-hist-track-back': '300',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-read-hist-track-slice': '10',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-read-hist-track-thresholds': '1,8,64',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-udf-hist-track-back': '300',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-udf-hist-track-slice': '10',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-udf-hist-track-thresholds': '1,8,64',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-write-hist-track-back': '300',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-write-hist-track-slice': '10',
	                                                        '{098f6bcd4621d373cade4e832627b4f6}-write-hist-track-thresholds': '1,8,64'},
	                  '37b51d194a7513e45b56f6524f2d51f2': { 'allow-nonxdr-writes': 'true',
	                                                        'allow-xdr-writes': 'true',
	                                                        'appeals_records_exonerated': '0',
	                                                        'appeals_rx_active': '0',
	                                                        'appeals_tx_active': '0',
	                                                        'appeals_tx_remaining': '0',
	                                                        'available_bin_names': '32768',
	                                                        'background-scan-max-rps': '10000',
	                                                        'batch_sub_proxy_complete': '0',
	                                                        'batch_sub_proxy_error': '0',
	                                                        'batch_sub_proxy_timeout': '0',
	                                                        'batch_sub_read_error': '0',
	                                                        'batch_sub_read_filtered_out': '0',
	                                                        'batch_sub_read_not_found': '0',
	                                                        'batch_sub_read_success': '0',
	                                                        'batch_sub_read_timeout': '0',
	                                                        'batch_sub_tsvc_error': '0',
	                                                        'batch_sub_tsvc_timeout': '0',
	                                                        'client_delete_error': '0',
	                                                        'client_delete_filtered_out': '0',
	                                                        'client_delete_not_found': '0',
	                                                        'client_delete_success': '0',
	                                                        'client_delete_timeout': '0',
	                                                        'client_lang_delete_success': '0',
	                                                        'client_lang_error': '0',
	                                                        'client_lang_read_success': '0',
	                                                        'client_lang_write_success': '0',
	                                                        'client_proxy_complete': '0',
	                                                        'client_proxy_error': '0',
	                                                        'client_proxy_timeout': '0',
	                                                        'client_read_error': '0',
	                                                        'client_read_filtered_out': '0',
	                                                        'client_read_not_found': '0',
	                                                        'client_read_success': '0',
	                                                        'client_read_timeout': '0',
	                                                        'client_tsvc_error': '0',
	                                                        'client_tsvc_timeout': '0',
	                                                        'client_udf_complete': '0',
	                                                        'client_udf_error': '0',
	                                                        'client_udf_filtered_out': '0',
	                                                        'client_udf_timeout': '0',
	                                                        'client_write_error': '0',
	                                                        'client_write_filtered_out': '0',
	                                                        'client_write_success': '0',
	                                                        'client_write_timeout': '0',
	                                                        'clock_skew_stop_writes': 'false',
	                                                        'conflict-resolution-policy': 'generation',
	                                                        'current_time': '313299633',
	                                                        'data-in-index': 'false',
	                                                        'dead_partitions': '0',
	                                                        'default-ttl': '2592000',
	                                                        'deleted_last_bin': '0',
	                                                        'disable-cold-start-eviction': 'false',
	                                                        'disable-write-dup-res': 'false',
	                                                        'disallow-null-setname': 'false',
	                                                        'effective_is_quiesced': 'false',
	                                                        'effective_prefer_uniform_balance': 'false',
	                                                        'effective_replication_factor': '0',
	                                                        'enable-benchmarks-batch-sub': 'false',
	                                                        'enable-benchmarks-read': 'false',
	                                                        'enable-benchmarks-udf': 'false',
	                                                        'enable-benchmarks-udf-sub': 'false',
	                                                        'enable-benchmarks-write': 'false',
	                                                        'enable-hist-proxy': 'false',
	                                                        'enable-xdr': 'false',
	                                                        'evict-hist-buckets': '10000',
	                                                        'evict-tenths-pct': '5',
	                                                        'evict_ttl': '0',
	                                                        'evict_void_time': '0',
	                                                        'evicted_objects': '0',
	                                                        'expired_objects': '0',
	                                                        'fail_generation': '0',
	                                                        'fail_key_busy': '0',
	                                                        'fail_record_too_big': '0',
	                                                        'fail_xdr_forbidden': '0',
	                                                        'from_proxy_batch_sub_read_error': '0',
	                                                        'from_proxy_batch_sub_read_filtered_out': '0',
	                                                        'from_proxy_batch_sub_read_not_found': '0',
	                                                        'from_proxy_batch_sub_read_success': '0',
	                                                        'from_proxy_batch_sub_read_timeout': '0',
	                                                        'from_proxy_batch_sub_tsvc_error': '0',
	                                                        'from_proxy_batch_sub_tsvc_timeout': '0',
	                                                        'from_proxy_delete_error': '0',
	                                                        'from_proxy_delete_filtered_out': '0',
	                                                        'from_proxy_delete_not_found': '0',
	                                                        'from_proxy_delete_success': '0',
	                                                        'from_proxy_delete_timeout': '0',
	                                                        'from_proxy_lang_delete_success': '0',
	                                                        'from_proxy_lang_error': '0',
	                                                        'from_proxy_lang_read_success': '0',
	                                                        'from_proxy_lang_write_success': '0',
	                                                        'from_proxy_read_error': '0',
	                                                        'from_proxy_read_filtered_out': '0',
	                                                        'from_proxy_read_not_found': '0',
	                                                        'from_proxy_read_success': '0',
	                                                        'from_proxy_read_timeout': '0',
	                                                        'from_proxy_tsvc_error': '0',
	                                                        'from_proxy_tsvc_timeout': '0',
	                                                        'from_proxy_udf_complete': '0',
	                                                        'from_proxy_udf_error': '0',
	                                                        'from_proxy_udf_filtered_out': '0',
	                                                        'from_proxy_udf_timeout': '0',
	                                                        'from_proxy_write_error': '0',
	                                                        'from_proxy_write_filtered_out': '0',
	                                                        'from_proxy_write_success': '0',
	                                                        'from_proxy_write_timeout': '0',
	                                                        'geo2dsphere-within.earth-radius-meters': '6371000',
	                                                        'geo2dsphere-within.level-mod': '1',
	                                                        'geo2dsphere-within.max-cells': '12',
	                                                        'geo2dsphere-within.max-level': '30',
	                                                        'geo2dsphere-within.min-level': '1',
	                                                        'geo2dsphere-within.strict': 'true',
	                                                        'geo_region_query_cells': '0',
	                                                        'geo_region_query_falsepos': '0',
	                                                        'geo_region_query_points': '0',
	                                                        'geo_region_query_reqs': '0',
	                                                        'high-water-disk-pct': '50',
	                                                        'high-water-memory-pct': '60',
	                                                        'hwm_breached': 'false',
	                                                        'index-stage-size': '1073741824',
	                                                        'index-type': 'undefined',
	                                                        'master_objects': '0',
	                                                        'master_tombstones': '0',
	                                                        'memory-size': '4294967296',
	                                                        'memory_free_pct': '100',
	                                                        'memory_used_bytes': '0',
	                                                        'memory_used_data_bytes': '0',
	                                                        'memory_used_index_bytes': '0',
	                                                        'memory_used_sindex_bytes': '0',
	                                                        'migrate-order': '5',
	                                                        'migrate-retransmit-ms': '5000',
	                                                        'migrate-sleep': '1',
	                                                        'migrate_record_receives': '0',
	                                                        'migrate_record_retransmits': '0',
	                                                        'migrate_records_skipped': '0',
	                                                        'migrate_records_transmitted': '0',
	                                                        'migrate_rx_instances': '0',
	                                                        'migrate_rx_partitions_active': '0',
	                                                        'migrate_rx_partitions_initial': '0',
	                                                        'migrate_rx_partitions_remaining': '0',
	                                                        'migrate_signals_active': '0',
	                                                        'migrate_signals_remaining': '0',
	                                                        'migrate_tx_instances': '0',
	                                                        'migrate_tx_partitions_active': '0',
	                                                        'migrate_tx_partitions_imbalance': '0',
	                                                        'migrate_tx_partitions_initial': '0',
	                                                        'migrate_tx_partitions_lead_remaining': '0',
	                                                        'migrate_tx_partitions_remaining': '0',
	                                                        'nodes_quiesced': '0',
	                                                        'non_expirable_objects': '0',
	                                                        'non_replica_objects': '0',
	                                                        'non_replica_tombstones': '0',
	                                                        'ns-forward-xdr-writes': 'false',
	                                                        'ns_cluster_size': '0',
	                                                        'nsup-hist-period': '3600',
	                                                        'nsup-period': '120',
	                                                        'nsup-threads': '1',
	                                                        'nsup_cycle_duration': '0',
	                                                        'objects': '0',
	                                                        'ops_sub_tsvc_error': '0',
	                                                        'ops_sub_tsvc_timeout': '0',
	                                                        'ops_sub_write_error': '0',
	                                                        'ops_sub_write_filtered_out': '0',
	                                                        'ops_sub_write_success': '0',
	                                                        'ops_sub_write_timeout': '0',
	                                                        'partition-tree-sprigs': '256',
	                                                        'pending_quiesce': 'false',
	                                                        'prefer-uniform-balance': 'false',
	                                                        'prole_objects': '0',
	                                                        'prole_tombstones': '0',
	                                                        'query_agg': '0',
	                                                        'query_agg_abort': '0',
	                                                        'query_agg_avg_rec_count': '0',
	                                                        'query_agg_error': '0',
	                                                        'query_agg_success': '0',
	                                                        'query_fail': '0',
	                                                        'query_long_queue_full': '0',
	                                                        'query_long_reqs': '0',
	                                                        'query_lookup_abort': '0',
	                                                        'query_lookup_avg_rec_count': '0',
	                                                        'query_lookup_error': '0',
	                                                        'query_lookup_success': '0',
	                                                        'query_lookups': '0',
	                                                        'query_ops_bg_failure': '0',
	                                                        'query_ops_bg_success': '0',
	                                                        'query_proto_compression_ratio': '1.000',
	                                                        'query_proto_uncompressed_pct': '0.000',
	                                                        'query_reqs': '0',
	                                                        'query_short_queue_full': '0',
	                                                        'query_short_reqs': '0',
	                                                        'query_udf_bg_failure': '0',
	                                                        'query_udf_bg_success': '0',
	                                                        'rack-id': '0',
	                                                        're_repl_error': '0',
	                                                        're_repl_success': '0',
	                                                        're_repl_timeout': '0',
	                                                        'read-consistency-level-override': 'off',
	                                                        'record_proto_compression_ratio': '1.000',
	                                                        'record_proto_uncompressed_pct': '0.000',
	                                                        'replication-factor': '2',
	                                                        'retransmit_all_batch_sub_dup_res': '0',
	                                                        'retransmit_all_delete_dup_res': '0',
	                                                        'retransmit_all_delete_repl_write': '0',
	                                                        'retransmit_all_read_dup_res': '0',
	                                                        'retransmit_all_udf_dup_res': '0',
	                                                        'retransmit_all_udf_repl_write': '0',
	                                                        'retransmit_all_write_dup_res': '0',
	                                                        'retransmit_all_write_repl_write': '0',
	                                                        'retransmit_ops_sub_dup_res': '0',
	                                                        'retransmit_ops_sub_repl_write': '0',
	                                                        'retransmit_udf_sub_dup_res': '0',
	                                                        'retransmit_udf_sub_repl_write': '0',
	                                                        'scan_aggr_abort': '0',
	                                                        'scan_aggr_complete': '0',
	                                                        'scan_aggr_error': '0',
	                                                        'scan_basic_abort': '0',
	                                                        'scan_basic_complete': '0',
	                                                        'scan_basic_error': '0',
	                                                        'scan_ops_bg_abort': '0',
	                                                        'scan_ops_bg_complete': '0',
	                                                        'scan_ops_bg_error': '0',
	                                                        'scan_proto_compression_ratio': '1.000',
	                                                        'scan_proto_uncompressed_pct': '0.000',
	                                                        'scan_udf_bg_abort': '0',
	                                                        'scan_udf_bg_complete': '0',
	                                                        'scan_udf_bg_error': '0',
	                                                        'sets-enable-xdr': 'true',
	                                                        'sindex.num-partitions': '32',
	                                                        'single-bin': 'false',
	                                                        'single-scan-threads': '4',
	                                                        'smd_evict_void_time': '0',
	                                                        'stop-writes-pct': '90',
	                                                        'stop_writes': 'false',
	                                                        'storage-engine': 'memory',
	                                                        'strong-consistency': 'false',
	                                                        'strong-consistency-allow-expunge': 'false',
	                                                        'tomb-raider-eligible-age': '86400',
	                                                        'tomb-raider-period': '86400',
	                                                        'tombstones': '0',
	                                                        'transaction-pending-limit': '20',
	                                                        'truncate-threads': '4',
	                                                        'truncate_lut': '0',
	                                                        'truncated_records': '0',
	                                                        'udf_sub_lang_delete_success': '0',
	                                                        'udf_sub_lang_error': '0',
	                                                        'udf_sub_lang_read_success': '0',
	                                                        'udf_sub_lang_write_success': '0',
	                                                        'udf_sub_tsvc_error': '0',
	                                                        'udf_sub_tsvc_timeout': '0',
	                                                        'udf_sub_udf_complete': '0',
	                                                        'udf_sub_udf_error': '0',
	                                                        'udf_sub_udf_filtered_out': '0',
	                                                        'udf_sub_udf_timeout': '0',
	                                                        'unavailable_partitions': '0',
	                                                        'write-commit-level-override': 'off',
	                                                        'xdr_client_delete_error': '0',
	                                                        'xdr_client_delete_not_found': '0',
	                                                        'xdr_client_delete_success': '0',
	                                                        'xdr_client_delete_timeout': '0',
	                                                        'xdr_client_write_error': '0',
	                                                        'xdr_client_write_success': '0',
	                                                        'xdr_client_write_timeout': '0',
	                                                        'xdr_from_proxy_delete_error': '0',
	                                                        'xdr_from_proxy_delete_not_found': '0',
	                                                        'xdr_from_proxy_delete_success': '0',
	                                                        'xdr_from_proxy_delete_timeout': '0',
	                                                        'xdr_from_proxy_write_error': '0',
	                                                        'xdr_from_proxy_write_success': '0',
	                                                        'xdr_from_proxy_write_timeout': '0',
	                                                        'xmem_id': '0',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-query-hist-track-back': '300',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-query-hist-track-slice': '10',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-query-hist-track-thresholds': '1,8,64',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-read-hist-track-back': '300',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-read-hist-track-slice': '10',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-read-hist-track-thresholds': '1,8,64',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-udf-hist-track-back': '300',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-udf-hist-track-slice': '10',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-udf-hist-track-thresholds': '1,8,64',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-write-hist-track-back': '300',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-write-hist-track-slice': '10',
	                                                        '{37b51d194a7513e45b56f6524f2d51f2}-write-hist-track-thresholds': '1,8,64'}},
	  'node': '3001:7f4c5ff6d6c801d253d9247a098fa286',
	  'partition-generation': '-1',
	  'service': '98315ce693114ad9d0229d5d1f59303a:3000',
	  'services': '',
	  'services-alternate': '',
	  'services-alumni': '44dde01af2643694c082906e5ef73f14:3000;a780fd5a2df6e68501d9b88b4e0fb4ca:3000',
	  'sets': [ { 'disable-eviction': 'false',
	              'memory_data_bytes': '0',
	              'ns': '098f6bcd4621d373cade4e832627b4f6',
	              'objects': '0',
	              'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	              'set-enable-xdr': 'use-default',
	              'stop-writes-count': '0',
	              'tombstones': '0',
	              'truncate_lut': '0'}],
	  'sindex-metadata': [ { 'bin': '9fdfaf35f228930acd95c5aa32584802',
	                         'indexname': '06a14196c66aa65c536919bc47ee888b',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '9fdfaf35f228930acd95c5aa32584802',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'},
	                       { 'bin': 'cf4d20e97469e02f3b6c2b232ab34f44',
	                         'indexname': '019c265185149af7571d8a83b4476a1f',
	                         'indextype': 'MAPKEYS',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': 'cf4d20e97469e02f3b6c2b232ab34f44',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'},
	                       { 'bin': '8b30fe44e499fb790e74f680235d8cd9',
	                         'indexname': '7962077652b6e505f760f02e1c96cc02',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '8b30fe44e499fb790e74f680235d8cd9',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'NUMERIC'},
	                       { 'bin': 'fe18431d7c0a68328e87a0281bbb4d75',
	                         'indexname': 'f1c2adcd32d1693c90eda23438bfc2ec',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': 'fe18431d7c0a68328e87a0281bbb4d75',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'},
	                       { 'bin': 'e3a22f741f62e982ecf988274bf06e7b',
	                         'indexname': '588d14a7bd46fb6158d6b401c90dc7e7',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': 'e3a22f741f62e982ecf988274bf06e7b',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'NUMERIC'},
	                       { 'bin': 'c9e5b89b86cd04815b808ae9d8a93422',
	                         'indexname': '9360feec57978773784898f8a3645afb',
	                         'indextype': 'MAPVALUES',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': 'c9e5b89b86cd04815b808ae9d8a93422',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'},
	                       { 'bin': '04566f2efd0c670f81993ee81356dcab',
	                         'indexname': '169bc308db6dd8321dc79173265761d8',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '04566f2efd0c670f81993ee81356dcab',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'},
	                       { 'bin': '623ce1edac40661eb81d763055d75e7a',
	                         'indexname': 'd912bdc3ded8b38e1f1a9ec76b346461',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '623ce1edac40661eb81d763055d75e7a',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'NUMERIC'},
	                       { 'bin': '65986795cdf1a8fade6a8a3ddb4eefc3',
	                         'indexname': '25c46124855ff17d274dc1d3a9411bad',
	                         'indextype': 'LIST',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '65986795cdf1a8fade6a8a3ddb4eefc3',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'},
	                       { 'bin': '7c232eef03e417ae252ed648f7846c13',
	                         'indexname': '81b6dbbaa60eaab3d68419889e21c4b6',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '7c232eef03e417ae252ed648f7846c13',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'NUMERIC'},
	                       { 'bin': '7dde332dd3b983633833c9f1895215ad',
	                         'indexname': '8761e52bd642fce002a3f406ce0dca6c',
	                         'indextype': 'MAPVALUES',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '7dde332dd3b983633833c9f1895215ad',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'NUMERIC'},
	                       { 'bin': '44d501d07586eb98861c77d62ce048e0',
	                         'indexname': 'ffc4b70ad1b5abee03323d0d7fca45c5',
	                         'indextype': 'LIST',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '44d501d07586eb98861c77d62ce048e0',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'NUMERIC'},
	                       { 'bin': 'c8cd1f08f26ae5de1d2d16f4a70e1789',
	                         'indexname': '8831a9ccec7a0125b12604619fea4aef',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': 'c8cd1f08f26ae5de1d2d16f4a70e1789',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'NUMERIC'},
	                       { 'bin': 'db1d6095be6fe9b316d9c228ec89e8e3',
	                         'indexname': '69a4d5f10be7644a8591e62869a65894',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': 'db1d6095be6fe9b316d9c228ec89e8e3',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'},
	                       { 'bin': '96b8393f16f865dd766b93b77328b29e',
	                         'indexname': 'd8877c9b6746509260dd078c7ff5e3c1',
	                         'indextype': 'NONE',
	                         'ns': '098f6bcd4621d373cade4e832627b4f6',
	                         'path': '96b8393f16f865dd766b93b77328b29e',
	                         'set': 'fe01ce2a7fbac8fafaed7c982a04e229',
	                         'state': 'RW',
	                         'type': 'STRING'}],
	  'sindexes': { '019c265185149af7571d8a83b4476a1f': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '06a14196c66aa65c536919bc47ee888b': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '169bc308db6dd8321dc79173265761d8': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '25c46124855ff17d274dc1d3a9411bad': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '588d14a7bd46fb6158d6b401c90dc7e7': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18432',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18432',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '69a4d5f10be7644a8591e62869a65894': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '7962077652b6e505f760f02e1c96cc02': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18432',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18432',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '81b6dbbaa60eaab3d68419889e21c4b6': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18432',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18432',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '8761e52bd642fce002a3f406ce0dca6c': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18432',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18432',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '8831a9ccec7a0125b12604619fea4aef': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18432',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18432',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                '9360feec57978773784898f8a3645afb': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                'd8877c9b6746509260dd078c7ff5e3c1': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                'd912bdc3ded8b38e1f1a9ec76b346461': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18432',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18432',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                'f1c2adcd32d1693c90eda23438bfc2ec': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18688',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18688',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'},
	                'ffc4b70ad1b5abee03323d0d7fca45c5': { 'delete_error': '0',
	                                                      'delete_success': '0',
	                                                      'entries': '0',
	                                                      'histogram': 'false',
	                                                      'ibtr_memory_used': '18432',
	                                                      'keys': '0',
	                                                      'load_pct': '100',
	                                                      'loadtime': '0',
	                                                      'nbtr_memory_used': '0',
	                                                      'query_agg': '0',
	                                                      'query_agg_avg_rec_count': '0',
	                                                      'query_agg_avg_record_size': '0',
	                                                      'query_avg_rec_count': '0',
	                                                      'query_avg_record_size': '0',
	                                                      'query_lookup_avg_rec_count': '0',
	                                                      'query_lookup_avg_record_size': '0',
	                                                      'query_lookups': '0',
	                                                      'query_reqs': '0',
	                                                      'si_accounted_memory': '18432',
	                                                      'stat_gc_recs': '0',
	                                                      'stat_gc_time': '0',
	                                                      'write_error': '0',
	                                                      'write_success': '0'}},
	  'statistics': { 'batch_index_complete': '0',
	                  'batch_index_created_buffers': '0',
	                  'batch_index_delay': '0',
	                  'batch_index_destroyed_buffers': '0',
	                  'batch_index_error': '0',
	                  'batch_index_huge_buffers': '0',
	                  'batch_index_initiate': '0',
	                  'batch_index_proto_compression_ratio': '1.000',
	                  'batch_index_proto_uncompressed_pct': '0.000',
	                  'batch_index_queue': '0:0,0:0,0:0,0:0',
	                  'batch_index_timeout': '0',
	                  'batch_index_unused_buffers': '0',
	                  'client_connections': '3',
	                  'cluster_clock_skew_ms': '0',
	                  'cluster_clock_skew_outliers': 'null',
	                  'cluster_clock_skew_stop_writes_sec': '0',
	                  'cluster_duplicate_nodes': 'null',
	                  'cluster_generation': '0',
	                  'cluster_integrity': 'false',
	                  'cluster_is_member': 'false',
	                  'cluster_key': '0',
	                  'cluster_principal': '3001:0d39073197a375aaf7df9fbb61e60067',
	                  'cluster_size': '3',
	                  'demarshal_error': '0',
	                  'early_tsvc_batch_sub_error': '0',
	                  'early_tsvc_client_error': '0',
	                  'early_tsvc_from_proxy_batch_sub_error': '0',
	                  'early_tsvc_from_proxy_error': '0',
	                  'early_tsvc_ops_sub_error': '0',
	                  'early_tsvc_udf_sub_error': '0',
	                  'fabric_bulk_recv_rate': '0',
	                  'fabric_bulk_send_rate': '0',
	                  'fabric_connections': '0',
	                  'fabric_ctrl_recv_rate': '0',
	                  'fabric_ctrl_send_rate': '0',
	                  'fabric_meta_recv_rate': '0',
	                  'fabric_meta_send_rate': '0',
	                  'fabric_rw_recv_rate': '0',
	                  'fabric_rw_send_rate': '0',
	                  'heap_active_kbytes': '2113044',
	                  'heap_allocated_kbytes': '2112593',
	                  'heap_efficiency_pct': '99',
	                  'heap_mapped_kbytes': '2142208',
	                  'heap_site_count': '0',
	                  'heartbeat_connections': '1',
	                  'heartbeat_received_foreign': '0',
	                  'heartbeat_received_self': '0',
	                  'info_complete': '17',
	                  'info_queue': '0',
	                  'migrate_allowed': 'false',
	                  'migrate_partitions_remaining': '0',
	                  'objects': '0',
	                  'paxos_principal': '3001:0d39073197a375aaf7df9fbb61e60067',
	                  'process_cpu_pct': '0',
	                  'proxy_in_progress': '0',
	                  'query_long_running': '0',
	                  'query_short_running': '0',
	                  'reaped_fds': '0',
	                  'rw_in_progress': '0',
	                  'scans_active': '0',
	                  'sindex_gc_garbage_cleaned': '0',
	                  'sindex_gc_garbage_found': '0',
	                  'sindex_gc_list_creation_time': '0',
	                  'sindex_gc_list_deletion_time': '0',
	                  'sindex_gc_objects_validated': '0',
	                  'sindex_gc_retries': '0',
	                  'sindex_ucgarbage_found': '0',
	                  'system_free_mem_pct': '99',
	                  'system_kernel_cpu_pct': '0',
	                  'system_total_cpu_pct': '0',
	                  'system_user_cpu_pct': '0',
	                  'time_since_rebalance': '15401097',
	                  'tombstones': '0',
	                  'tree_gc_queue': '0',
	                  'uptime': '1'},
	  'succession-list': '3001:0d39073197a375aaf7df9fbb61e60067,3001:067df70da67cd6c36ad7b910bb959938,3001:efba5fc8eb3db7fff983c6fc82ccf177',
	  'system': { 'CPU information': [ 'CPUInfoBase__get_nbits=64',
	                                   'getNCPUs=4',
	                                   'has_mmx',
	                                   'has_sse',
	                                   'has_sse2',
	                                   'has_sse3',
	                                   'has_ssse3',
	                                   'is_64bit',
	                                   'is_Intel',
	                                   'is_i686',
	                                   [ { 'address sizes': '36 bits physical, 48 bits virtual',
	                                       'apicid': '0',
	                                       'bogomips': '6419.44',
	                                       'cache size': '6144 KB',
	                                       'cache_alignment': '64',
	                                       'clflush size': '64',
	                                       'core id': '0',
	                                       'cpu MHz': '1600.000',
	                                       'cpu cores': '4',
	                                       'cpu family': '6',
	                                       'cpuid level': '13',
	                                       'flags': 'fpu vme de pse tsc msr pae mce cx8 apic mtrr pge mca cmov pat pse36 clflush dts acpi mmx fxsr sse sse2 ss ht tm pbe syscall nx rdtscp lm constant_tsc arch_perfmon pebs bts rep_good xtopology nonstop_tsc aperfmperf pni pclmulqdq dtes64 monitor ds_cpl vmx smx est tm2 ssse3 cx16 xtpr pdcm sse4_1 sse4_2 x2apic popcnt aes xsave avx f16c rdrand lahf_lm ida arat epb xsaveopt pln pts dts tpr_shadow vnmi flexpriority ept vpid fsgsbase smep erms',
	                                       'fpu': 'yes',
	                                       'fpu_exception': 'yes',
	                                       'initial apicid': '0',
	                                       'model': '58',
	                                       'model name': 'Intel(R) Core(TM) i5-3470 CPU @ 3.20GHz',
	                                       'physical id': '0',
	                                       'power management': '',
	                                       'processor': '0',
	                                       'siblings': '4',
	                                       'stepping': '9',
	                                       'uname_m': 'x86_64',
	                                       'vendor_id': 'GenuineIntel',
	                                       'wp': 'yes'},
	                                     { 'address sizes': '36 bits physical, 48 bits virtual',
	                                       'apicid': '2',
	                                       'bogomips': '6419.44',
	                                       'cache size': '6144 KB',
	                                       'cache_alignment': '64',
	                                       'clflush size': '64',
	                                       'core id': '1',
	                                       'cpu MHz': '3201.000',
	                                       'cpu cores': '4',
	                                       'cpu family': '6',
	                                       'cpuid level': '13',
	                                       'flags': 'fpu vme de pse tsc msr pae mce cx8 apic mtrr pge mca cmov pat pse36 clflush dts acpi mmx fxsr sse sse2 ss ht tm pbe syscall nx rdtscp lm constant_tsc arch_perfmon pebs bts rep_good xtopology nonstop_tsc aperfmperf pni pclmulqdq dtes64 monitor ds_cpl vmx smx est tm2 ssse3 cx16 xtpr pdcm sse4_1 sse4_2 x2apic popcnt aes xsave avx f16c rdrand lahf_lm ida arat epb xsaveopt pln pts dts tpr_shadow vnmi flexpriority ept vpid fsgsbase smep erms',
	                                       'fpu': 'yes',
	                                       'fpu_exception': 'yes',
	                                       'initial apicid': '2',
	                                       'model': '58',
	                                       'model name': 'Intel(R) Core(TM) i5-3470 CPU @ 3.20GHz',
	                                       'physical id': '0',
	                                       'power management': '',
	                                       'processor': '1',
	                                       'siblings': '4',
	                                       'stepping': '9',
	                                       'vendor_id': 'GenuineIntel',
	                                       'wp': 'yes'},
	                                     { 'address sizes': '36 bits physical, 48 bits virtual',
	                                       'apicid': '4',
	                                       'bogomips': '6419.44',
	                                       'cache size': '6144 KB',
	                                       'cache_alignment': '64',
	                                       'clflush size': '64',
	                                       'core id': '2',
	                                       'cpu MHz': '1600.000',
	                                       'cpu cores': '4',
	                                       'cpu family': '6',
	                                       'cpuid level': '13',
	                                       'flags': 'fpu vme de pse tsc msr pae mce cx8 apic mtrr pge mca cmov pat pse36 clflush dts acpi mmx fxsr sse sse2 ss ht tm pbe syscall nx rdtscp lm constant_tsc arch_perfmon pebs bts rep_good xtopology nonstop_tsc aperfmperf pni pclmulqdq dtes64 monitor ds_cpl vmx smx est tm2 ssse3 cx16 xtpr pdcm sse4_1 sse4_2 x2apic popcnt aes xsave avx f16c rdrand lahf_lm ida arat epb xsaveopt pln pts dts tpr_shadow vnmi flexpriority ept vpid fsgsbase smep erms',
	                                       'fpu': 'yes',
	                                       'fpu_exception': 'yes',
	                                       'initial apicid': '4',
	                                       'model': '58',
	                                       'model name': 'Intel(R) Core(TM) i5-3470 CPU @ 3.20GHz',
	                                       'physical id': '0',
	                                       'power management': '',
	                                       'processor': '2',
	                                       'siblings': '4',
	                                       'stepping': '9',
	                                       'vendor_id': 'GenuineIntel',
	                                       'wp': 'yes'},
	                                     { 'address sizes': '36 bits physical, 48 bits virtual',
	                                       'apicid': '6',
	                                       'bogomips': '6419.44',
	                                       'cache size': '6144 KB',
	                                       'cache_alignment': '64',
	                                       'clflush size': '64',
	                                       'core id': '3',
	                                       'cpu MHz': '3201.000',
	                                       'cpu cores': '4',
	                                       'cpu family': '6',
	                                       'cpuid level': '13',
	                                       'flags': 'fpu vme de pse tsc msr pae mce cx8 apic mtrr pge mca cmov pat pse36 clflush dts acpi mmx fxsr sse sse2 ss ht tm pbe syscall nx rdtscp lm constant_tsc arch_perfmon pebs bts rep_good xtopology nonstop_tsc aperfmperf pni pclmulqdq dtes64 monitor ds_cpl vmx smx est tm2 ssse3 cx16 xtpr pdcm sse4_1 sse4_2 x2apic popcnt aes xsave avx f16c rdrand lahf_lm ida arat epb xsaveopt pln pts dts tpr_shadow vnmi flexpriority ept vpid fsgsbase smep erms',
	                                       'fpu': 'yes',
	                                       'fpu_exception': 'yes',
	                                       'initial apicid': '6',
	                                       'model': '58',
	                                       'model name': 'Intel(R) Core(TM) i5-3470 CPU @ 3.20GHz',
	                                       'physical id': '0',
	                                       'power management': '',
	                                       'processor': '3',
	                                       'siblings': '4',
	                                       'stepping': '9',
	                                       'vendor_id': 'GenuineIntel',
	                                       'wp': 'yes'}]],
	              'linux_distribution': ('CentOS', '6.3', 'Final'),
	              'os-name': 'posix',
	              'platform': 'linux2',
	              'python_version': '2.6.6 (r266:84292, Jul 23 2015, 15:22:56) \n[GCC 4.4.7 20120313 (Red Hat 4.4.7-11)]',
	              'uname': [ 'Linux',
	                         '9948c645c094247794f4c7acdbeb2bb6',
	                         '2.6.32-279.19.1.el6.x86_64',
	                         '#1 SMP Wed Dec 19 07:05:20 UTC 2012',
	                         'x86_64',
	                         'x86_64']},
	  'telemetry-agent-ip-address': '98315ce693114ad9d0229d5d1f59303a',
	  'telemetry-agent-version': '1.0.12',
	  'udfs': { 'num-udf-files': '4'},
	  'unix-epoch-time': '1575603633',
	  'version': 'Aerospike Community Edition build 4.7.0.5'}
